==> jabber-transport-0.9.tar.gz: jabber-transport-0.9/src/modules/mod_agents.c <==
#include "jserver.h"

mreturn mod_agents_agents(mapi m)
{
    xmlnode ret, retq, agents;

    /* get data from the config file */
    agents = js_config("agents");

    /* if we don't have anything to say, bounce */
    if(agents == NULL)
        return M_PASS;

    log_debug("mod_agents","handling agents query");

    /* build the result IQ */
    ret = js_iqreply(m->packet->x);
    retq = xmlnode_insert_tag(ret,"query");
    xmlnode_put_attrib(retq,"xmlns",NS_AGENTS);

    /* copy in the agents */
    xmlnode_insert_node(retq,xmlnode_get_firstchild(agents));

    jpacket_reset(m->packet);
    js_deliver(m->packet);

    return M_HANDLED;
}

mreturn mod_agents_agent(mapi m)
{
    xmlnode ret, retq, info, agents, reg;

    /* get data from the config file */
    info = js_config("info");
    agents = js_config("agents");
    reg = js_config("register");

    /* if we don't have anything to say, bounce */
    if(info == NULL && agents == NULL && reg == NULL)
        return M_PASS;

    log_debug("mod_agent","handling agent query");

    /* build the result IQ */
    ret = js_iqreply(m->packet->x);
    retq = xmlnode_insert_tag(ret,"query");
    xmlnode_put_attrib(retq,"xmlns",NS_AGENT);

    /* copy in the info */
    xmlnode_insert_node(retq,xmlnode_get_firstchild(info));
    xmlnode_insert_cdata(xmlnode_insert_tag(retq,"service"),"jabber",6);

    /* set the flags */
    if(agents != NULL)
        xmlnode_insert_tag(retq,"agents");
    if(reg != NULL)
        xmlnode_insert_tag(retq,"register");

    jpacket_reset(m->packet);
    js_deliver(m->packet);

    return M_HANDLED;
}

mreturn mod_agents_handler(mapi m, void *arg)
{
    if(m->packet->type != JPACKET_IQ) return M_IGNORE;

    if(jpacket_subtype(m->packet) != JPACKET__GET) return M_PASS;

    if(NSCHECK(m->packet->iq,NS_AGENT)) return mod_agents_agent(m);
    if(NSCHECK(m->packet->iq,NS_AGENTS)) return mod_agents_agents(m);
}

void mod_agents(void)
{
    log_debug("mod_agents","init");
    js_mapi_register(P_SERVER, mod_agents_handler, NULL);
}

==> jabber-transport-1.0.tar.gz: jabber-transport-1.0/src/modules/mod_agents.c <==
#include "jserver.h"

mreturn mod_agents_agents(mapi m)
{
    xmlnode ret, retq, agents;

    /* get data from the config file */
    agents = js_config("agents");

    /* if we don't have anything to say, bounce */
    if(agents == NULL)
        return M_PASS;

    log_debug("mod_agents","handling agents query");

    /* build the result IQ */
    ret = jutil_iqresult(m->packet->x);
    retq = xmlnode_insert_tag(ret,"query");
    xmlnode_put_attrib(retq,"xmlns",NS_AGENTS);

    /* copy in the agents */
    xmlnode_insert_node(retq,xmlnode_get_firstchild(agents));

    jpacket_reset(m->packet);
    js_deliver(m->packet);

    return M_HANDLED;
}

mreturn mod_agents_agent(mapi m)
{
    xmlnode ret, retq, info, agents, reg;

    /* get data from the config file */
    info = js_config("info");
    agents = js_config("agents");
    reg = js_config("register");

    /* if we don't have anything to say, bounce */
    if(info == NULL && agents == NULL && reg == NULL)
        return M_PASS;

    log_debug("mod_agent","handling agent query");

    /* build the result IQ */
    ret = jutil_iqresult(m->packet->x);
    retq = xmlnode_insert_tag(ret,"query");
    xmlnode_put_attrib(retq,"xmlns",NS_AGENT);

    /* copy in the info */
    xmlnode_insert_node(retq,xmlnode_get_firstchild(info));
    xmlnode_insert_cdata(xmlnode_insert_tag(retq,"service"),"jabber",6);

    /* set the flags */
    if(agents != NULL)
        xmlnode_insert_tag(retq,"agents");
    if(reg != NULL)
        xmlnode_insert_tag(retq,"register");

    jpacket_reset(m->packet);
    js_deliver(m->packet);

    return M_HANDLED;
}

mreturn mod_agents_handler(mapi m, void *arg)
{
    if(m->packet->type != JPACKET_IQ) return M_IGNORE;

    if(jpacket_subtype(m->packet) != JPACKET__GET) return M_PASS;

    if(NSCHECK(m->packet->iq,NS_AGENT)) return mod_agents_agent(m);
    if(NSCHECK(m->packet->iq,NS_AGENTS)) return mod_agents_agents(m);

    return M_PASS;
}

void mod_agents(void)
{
    log_debug("mod_agents","init");
    js_mapi_register(P_SERVER, mod_agents_handler, NULL);
}
